import 'package:flutter/material.dart';
import 'package:flutter_inappwebview/flutter_inappwebview.dart';
import 'package:senior_authentication/senior_authentication.dart';

class ForgotPasswordRecaptcha extends StatefulWidget {
  const ForgotPasswordRecaptcha({
    Key? key,
    required this.changePasswordSetting,
  }) : super(key: key);

  final ChangePasswordSettings changePasswordSetting;

  @override
  _ForgotPasswordRecaptchaState createState() => _ForgotPasswordRecaptchaState(
        changePasswordSetting: changePasswordSetting,
      );
}

class _ForgotPasswordRecaptchaState extends State<ForgotPasswordRecaptcha> {
  final ChangePasswordSettings changePasswordSetting;
  String? _urlFrontendRecaptcha;
  double progress = 0;

  _ForgotPasswordRecaptchaState({required this.changePasswordSetting}) {
    _getUrlRecaptchaFrontend(changePasswordSetting.customRecaptchaSiteKey ?? '')
        .then((value) {
      setState(() {
        this._urlFrontendRecaptcha = value;
      });
    });
  }

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        iconTheme: const IconThemeData(color: Colors.black87),
        backgroundColor: Colors.white,
        shadowColor: Colors.transparent,
        title: const Text(
          'Validação de Segurança',
          style: TextStyle(color: Colors.black87),
        ),
      ),
      backgroundColor: const Color(0xAF000000),
      body: Stack(
        children: [
          progress < 1.0
              ? const Center(
                  child: SizedBox(
                    height: 50,
                    width: 50,
                    child: CircularProgressIndicator(
                      backgroundColor: Color(0xFF12A885),
                      strokeWidth: 5,
                      valueColor: AlwaysStoppedAnimation<Color>(
                        Color(0xFF0E866A),
                      ),
                    ),
                  ),
                )
              : const SizedBox(),
          _urlFrontendRecaptcha != null
              ? InAppWebView(
                  initialOptions: InAppWebViewGroupOptions(
                    crossPlatform: InAppWebViewOptions(
                      transparentBackground: true,
                      horizontalScrollBarEnabled: false,
                      verticalScrollBarEnabled: false,
                    ),
                    android: AndroidInAppWebViewOptions(
                      useHybridComposition: true,
                    ),
                  ),
                  initialUrlRequest: URLRequest(
                    url: Uri.parse(
                      _urlFrontendRecaptcha!,
                    ),
                  ),
                  onProgressChanged: (controller, progress) {
                    setState(() {
                      this.progress = progress / 100;
                    });
                  },
                  onConsoleMessage: (controller, response) {
                    final message = response.message;

                    if (message.contains('recaptcha_success=')) {
                      final captcha =
                          message.replaceAll('recaptcha_success=', '');
                      if (captcha.isNotEmpty) {
                        Navigator.of(context).pop(captcha);
                      } else {
                        _recaptchaErrorSnackBar(context);
                      }
                    } else if (message.contains('recaptcha_error=')) {
                      _recaptchaErrorSnackBar(context);
                    }
                  },
                )
              : SizedBox(),
        ],
      ),
    );
  }

  void _recaptchaErrorSnackBar(BuildContext context) {
    ScaffoldMessenger.of(context)
      ..hideCurrentSnackBar()
      ..showSnackBar(
        const SnackBar(
          content: Text('Erro na validação. Tente novamente!'),
        ),
      );
  }

  Future<String> _getUrlRecaptchaFrontend(String key) async {
    var url = await AuthenticationRepository().getRecaptchaUrl();
    return '$url${key.isNotEmpty ? '?siteKey=$key' : ''}';
  }
}
